summaryrefslogtreecommitdiffstats
path: root/net/http/http_server_properties.h
diff options
context:
space:
mode:
authorrtenneti@chromium.org <rtenneti@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-04-30 21:13:09 +0000
committerrtenneti@chromium.org <rtenneti@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-04-30 21:13:09 +0000
commit6dd1134ebf789b23d79c2ff09126fbf82e9d4d68 (patch)
treeba1c0773c5de4d4a34f543d3e8791ac4ccbb3a07 /net/http/http_server_properties.h
parentcdcce8de8d45bfffd66f1e8cdca9ec5da906e6f2 (diff)
downloadchromium_src-6dd1134ebf789b23d79c2ff09126fbf82e9d4d68.zip
chromium_src-6dd1134ebf789b23d79c2ff09126fbf82e9d4d68.tar.gz
chromium_src-6dd1134ebf789b23d79c2ff09126fbf82e9d4d68.tar.bz2
SPDY: Respect SETTINGS_FLAG_CLEAR_PREVIOUSLY_PERSISTED_SETTINGS.
- Added ClearSpdySettings API call to clear the persisted SPDY setting data for a given host. SpdySession's OnSettings API calls this method to clear the persisted data. - ClearAllSpdySettings clears all the persisted data. - Add SpdyFramerVisitorInterface::OnSettings(). No behavioral change (no compiled change) outside tests. Merge internal change: 45922004 R=rch@chromium.org TEST=net unit tests and browser unit tests BUG=235737 Review URL: https://chromiumcodereview.appspot.com/14583002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@197469 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/http/http_server_properties.h')
-rw-r--r--net/http/http_server_properties.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/net/http/http_server_properties.h b/net/http/http_server_properties.h
index 8d14d3b..28a608f 100644
--- a/net/http/http_server_properties.h
+++ b/net/http/http_server_properties.h
@@ -102,8 +102,11 @@ class NET_EXPORT HttpServerProperties {
SpdySettingsFlags flags,
uint32 value) = 0;
- // Clears all SPDY settings.
- virtual void ClearSpdySettings() = 0;
+ // Clears all SPDY settings for a host.
+ virtual void ClearSpdySettings(const HostPortPair& host_port_pair) = 0;
+
+ // Clears all SPDY settings for all hosts.
+ virtual void ClearAllSpdySettings() = 0;
// Returns all persistent SPDY settings.
virtual const SpdySettingsMap& spdy_settings_map() const = 0;